@@ -24,25 +24,14 @@ You should not need to import this if you use usb1 module.
 Declares all constants, data structures and exported symbols.
 Locates and loads libusb1 dynamic library.
 """
-from ctypes import Structure, LittleEndianStructure, \
-    CFUNCTYPE, POINTER, addressof, sizeof, cast, \
-    c_short, c_int, c_uint, c_size_t, c_long, \
-    c_uint8, c_uint16, c_uint32, \
-    c_void_p, c_char_p, py_object, pointer, c_char
-try:
-    from ctypes import c_ssize_t
-except ImportError:
-    from ctypes import c_longlong
-    # c_ssize_t is new in Python 2.7
-    if sizeof(c_int) == sizeof(c_size_t):
-        c_ssize_t = c_int
-    elif sizeof(c_long) == sizeof(c_size_t):
-        c_ssize_t = c_long
-    elif sizeof(c_longlong) == sizeof(c_size_t):
-        c_ssize_t = c_longlong
-    else:
-        raise ValueError('Unsupported arch: sizeof(c_size_t) = %r' % (
-            sizeof(c_size_t), ))
+from ctypes import (
+    Structure, LittleEndianStructure,
+    CFUNCTYPE, POINTER, addressof, sizeof, cast,
+    c_short, c_int, c_uint, c_size_t, c_long,
+    c_uint8, c_uint16, c_uint32,
+    c_void_p, c_char_p, py_object, pointer, c_char,
+    c_ssize_t, CDLL
+)
 import ctypes.util
 import platform
 import os.path
@@ -158,12 +147,14 @@ def _loadLibrary():
     else:
         dll_loader = ctypes.CDLL
         suffix = system == 'Darwin' and '.dylib' or '.so'
-    loader_kw = {}
-    if sys.version_info[:2] >= (2, 6):
-        loader_kw['use_errno'] = True
-        loader_kw['use_last_error'] = True
+    filename = 'libusb-1.0' + suffix
+    # If this is a binary wheel, use the integrated libusb unconditionally.
+    # To use the libusb from the Python installation or the OS, install from sdist:
+    #   > pip install --no-binary :all: libusb1
+    if os.path.exists(os.path.join(os.path.dirname(__file__), filename)):
+        filename = os.path.join(os.path.dirname(__file__), filename)
     try:
-        return dll_loader('libusb-1.0' + suffix, **loader_kw)
+        return dll_loader(filename, use_errno=True, use_last_error=True)
     except OSError:
         libusb_path = None
         base_name = 'usb-1.0'
@@ -187,7 +178,7 @@ def _loadLibrary():
             libusb_path = ctypes.util.find_library(base_name)
             if libusb_path is None:
                 raise
-        return dll_loader(libusb_path, **loader_kw)
+        return dll_loader(libusb_path, use_errno=True, use_last_error=True)
 
 libusb = _loadLibrary()
 
@@ -1264,6 +1255,16 @@ libusb_set_pollfd_notifiers.argtypes = [libusb_context_p,
                                         libusb_pollfd_added_cb_p,
                                         libusb_pollfd_removed_cb_p, py_object]
 libusb_set_pollfd_notifiers.restype = None
+try:
+    #void libusb_get_pollfds(const struct libusb_pollfd **);
+    libusb_free_pollfds = libusb.libusb_free_pollfds
+    libusb_free_pollfds.argtypes = [libusb_pollfd_p_p]
+    libusb_free_pollfds.restype = None
+except AttributeError:
+    # Not a safe replacement in general, but the versions of libusb that lack
+    # libusb_free_pollfds() only provide that function on *nix, where
+    # Python's free() and libusb's free() are ~always the same anyways.
+    libusb_free_pollfds = CDLL(None).free
 
 #typedef int libusb_hotplug_callback_handle;
 libusb_hotplug_callback_handle = c_int
